# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PipelineListV1Params"]


class PipelineListV1Params(TypedDict, total=False):
    account_id: Required[str]
    """Specifies the public ID of the account."""

    name: str
    """Filters pipelines by name (case-insensitive substring)."""

    page: float

    per_page: float
