# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tenant_custom_nameserver_get_response import (
    TenantCustomNameserverGetResponse as TenantCustomNameserverGetResponse,
)
from .tenant_custom_nameserver_create_params import (
    TenantCustomNameserverCreateParams as TenantCustomNameserverCreateParams,
)
from .tenant_custom_nameserver_create_response import (
    TenantCustomNameserverCreateResponse as TenantCustomNameserverCreateResponse,
)
from .tenant_custom_nameserver_delete_response import (
    TenantCustomNameserverDeleteResponse as TenantCustomNameserverDeleteResponse,
)
